@@ -25,7 +25,6 @@
 
 #include "zenity.h"
 #include <stdlib.h>
-#include <locale.h>
 #include <popt.h>
 #include <langinfo.h>
 #ifdef HAVE_LOCALE_H
@@ -1353,7 +1352,7 @@ zenity_parse_options_callback (poptContext              ctx,
        * parse_options_callback gets called for each option. Suckage 
        */ 
       
-      if (parse_option_file > 2) 
+      if (parse_option_editable > 2) 
         zenity_error ("--editable", ERROR_DUPLICATE); 
       
       switch (results->mode) { 
@@ -1405,18 +1404,18 @@ zenity_parse_options_callback (poptContext              ctx,
       break; 
     case OPTION_CHECKLIST: 
       if (results->mode != MODE_LIST) 
-        zenity_error ("--checkbox", ERROR_SUPPORT); 
+        zenity_error ("--checklist", ERROR_SUPPORT); 
       
       if (results->tree_data->checkbox) 
-        zenity_error ("--checkbox", ERROR_DUPLICATE); 
+        zenity_error ("--checklist", ERROR_DUPLICATE); 
       
       results->tree_data->checkbox = TRUE; 
       break; 
     case OPTION_RADIOLIST: 
       if (results->mode != MODE_LIST) 
-        zenity_error ("--radiobox", ERROR_SUPPORT); 
+        zenity_error ("--radiolist", ERROR_SUPPORT); 
       if (results->tree_data->radiobox) 
-        zenity_error ("--radiobox", ERROR_DUPLICATE); 
+        zenity_error ("--radiolist", ERROR_DUPLICATE); 
       
       results->tree_data->radiobox = TRUE; 
       break; 
